@@ -20,7 +20,7 @@ sys.path.insert(0, os.path.abspath('../..'))
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    'sphinx.ext.autodoc',
+    'sphinxcontrib.apidoc',
     #'sphinx.ext.intersphinx',
     'openstackdocstheme'
 ]
@@ -46,7 +46,12 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
+
+# openstackdocstheme options
+openstackdocs_repo_name = 'openstack/sushy'
+openstackdocs_use_storyboard = True
+openstackdocs_pdf_link = True
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -59,6 +64,12 @@ html_theme = 'openstackdocs'
 # Output file base name for HTML help builder.
 htmlhelp_basename = 'sushydoc'
 
+# The openstackdocstheme 2.1.0 extension stopped always overriding latex_engine
+# to 'xelatex'. We need the 'xelatex' engine in order to handle some Unicode
+# characters we use in our feature classification matrix, like the "X" mark, so
+# we specify it here.
+latex_engine = 'xelatex'
+
 latex_use_xindy = False
 
 # Grouping the document tree into LaTeX files. List of tuples
@@ -73,3 +84,11 @@ latex_documents = [
 
 # Example configuration for intersphinx: refer to the Python standard library.
 #intersphinx_mapping = {'http://docs.python.org/': None}
+
+# -- sphinxcontrib.apidoc configuration --------------------------------------
+
+apidoc_module_dir = '../../sushy'
+apidoc_output_dir = 'reference/api'
+apidoc_excluded_paths = [
+    'tests',
+]
