@@ -15,15 +15,12 @@
 import abc
 import logging
 
-import six
-
 from sushy import exceptions
 
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AuthBase(object):
+class AuthBase(object, metaclass=abc.ABCMeta):
 
     def __init__(self, username=None, password=None):
         """A class representing a base Sushy authentication mechanism
@@ -152,18 +149,26 @@ class SessionAuth(AuthBase):
         :raises: AccessError
         :raises: HTTPError
         """
+        target_uri = None
+        try:
+            target_uri = self._root_resource.get_sessions_path()
+        except exceptions.MissingAttributeError:
+            LOG.debug('Missing Sessions attribute under Links in Root '
+                      'Service, we\'ll try to determine it from Session '
+                      'Service')
         session_service = self._root_resource.get_session_service()
         session_auth_token, session_uri = (
             session_service.create_session(self._username,
-                                           self._password))
+                                           self._password,
+                                           target_uri=target_uri))
         self._session_key = session_auth_token
         self._session_resource_id = session_uri
         self._connector.set_http_session_auth(session_auth_token)
 
     def can_refresh_session(self):
         """Method to assert if session based refresh can be done."""
-        return (self._session_key is not None and
-                self._session_resource_id is not None)
+        return (self._session_key is not None
+                and self._session_resource_id is not None)
 
     def refresh_session(self):
         """Method to refresh a session to a Redfish controller.
@@ -202,6 +207,16 @@ class SessionAuth(AuthBase):
         """Reset active session related attributes."""
         self._session_key = None
         self._session_resource_id = None
+        # Requests session object data is merged with user submitted data
+        # per https://requests.readthedocs.io/en/master/user/advanced/
+        # so we need to clear data explicitly set on the session too.
+        self._connector._session.auth = None
+        if 'X-Auth-Token' in self._connector._session.headers:
+            # Delete the token value that was saved to the session
+            # as otherwise we would end up with a dictionary containing
+            # a {'X-Auth-Token': null} being sent across to the remote
+            # bmc.
+            del self._connector._session.headers['X-Auth-Token']
 
 
 class SessionOrBasicAuth(SessionAuth):
