@@ -15,24 +15,16 @@
 
 import abc
 import collections
-
-# (rpittau) this allows usage of collection ABC abstract classes in both
-# Python 2.7 and Python 3.8+
-try:
-    collectionsAbc = collections.abc
-except AttributeError:
-    collectionsAbc = collections
-
 import copy
 import io
 import json
 import logging
-import pkg_resources
 import zipfile
 
-import six
+import pkg_resources
 
 from sushy import exceptions
+from sushy.resources import mappings as res_maps
 from sushy.resources import oem
 from sushy import utils
 
@@ -49,10 +41,9 @@ class Field(object):
 
         :param path: JSON field to fetch the value from. Either a string,
             or a list of strings in case of a nested field.
-        :param required: whether this field is required. Missing required
-            fields result in MissingAttributeError.
+        :param required: whether this field is required. Missing required,
+            but not defaulted, fields result in MissingAttributeError.
         :param default: the default value to use when the field is missing.
-            Only has effect when the field is not required.
         :param adapter: a function to call to transform and/or validate
             the received value. UnicodeError, ValueError or TypeError from
             this call are reraised as MalformedAttributeError.
@@ -89,7 +80,8 @@ class Field(object):
         :param resource: ResourceBase instance for which the field is loaded.
         :param nested_in: parent resource path (for error reporting only),
             must be a list of strings or None.
-        :raises: MissingAttributeError if a required field is missing.
+        :raises: MissingAttributeError if a required field is missing
+            and not defaulted.
         :raises: MalformedAttributeError on invalid field value or type.
         :returns: loaded and verified value
         """
@@ -103,23 +95,25 @@ class Field(object):
         except KeyError:
             if self._required:
                 path = (nested_in or []) + self._path
-                raise exceptions.MissingAttributeError(
-                    attribute='/'.join(path),
-                    resource=resource.path)
-            else:
-                # Do not run the adapter on the default value
-                return self._default
+
+                if self._default is None:
+                    raise exceptions.MissingAttributeError(
+                        attribute='/'.join(path),
+                        resource=resource.path)
+
+                logging.warning(
+                    'Applying default "%s" on required, but missing '
+                    'attribute "%s"' % (self._default, path))
+
+            # Do not run the adapter on the default value
+            return self._default
+
+        # NOTE(etingof): this is just to account for schema violation
+        if item is None:
+            return
 
         try:
-            # Get the value based on the name, defaulting to an empty dict
-            # Check to ensure that value is implemented by OEM
-            # TODO(etingof): we should revisit this logic/code
-            if (item is not None and item != {} and
-               str(item).lower() != 'none'):
-                value = self._adapter(item)
-
-            else:
-                value = item
+            return self._adapter(item)
 
         except (UnicodeError, ValueError, TypeError) as exc:
             path = (nested_in or []) + self._path
@@ -128,8 +122,6 @@ class Field(object):
                 resource=resource.path,
                 error=exc)
 
-        return value
-
 
 def _collect_fields(resource):
     """Collect fields from the JSON.
@@ -143,8 +135,7 @@ def _collect_fields(resource):
             yield (attr, field)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class CompositeField(collectionsAbc.Mapping, Field):
+class CompositeField(collections.abc.Mapping, Field, metaclass=abc.ABCMeta):
     """Base class for fields consisting of several sub-fields."""
 
     def __init__(self, *args, **kwargs):
@@ -175,7 +166,6 @@ class CompositeField(collectionsAbc.Mapping, Field):
         return instance
 
     # Satisfy the mapping interface, see
-    # https://docs.python.org/2/library/collections.html#collections.Mapping.
     # https://docs.python.org/3/library/collections.abc.html#collections.abc.Mapping
 
     def __getitem__(self, key):
@@ -268,13 +258,12 @@ class MappedField(Field):
             a string or a list of string. In the latter case, the value will
             be fetched from a nested object.
         :param mapping: a mapping to take values from.
-        :param required: whether this field is required. Missing required
-            fields result in MissingAttributeError.
+        :param required: whether this field is required. Missing required,
+            but not defaulted, fields result in MissingAttributeError.
         :param default: the default value to use when the field is missing.
-            Only has effect when the field is not required. This value is not
-            matched against the mapping.
+            This value is not matched against the mapping.
         """
-        if not isinstance(mapping, collectionsAbc.Mapping):
+        if not isinstance(mapping, collections.abc.Mapping):
             raise TypeError("The mapping argument must be a mapping")
 
         super(MappedField, self).__init__(
@@ -295,12 +284,11 @@ class MappedListField(Field):
 
         :param field: JSON field to fetch the list of values from.
         :param mapping: a mapping for the list elements.
-        :param required: whether this field is required. Missing required
-            fields result in MissingAttributeError.
+        :param required: whether this field is required. Missing required,
+            but not defaulted, fields result in MissingAttributeError.
         :param default: the default value to use when the field is missing.
-            Only has effect when the field is not required.
         """
-        if not isinstance(mapping, collectionsAbc.Mapping):
+        if not isinstance(mapping, collections.abc.Mapping):
             raise TypeError("The mapping argument must be a mapping")
 
         self._mapping_adapter = mapping.get
@@ -328,8 +316,61 @@ class MappedListField(Field):
         return instances
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractJsonReader(object):
+class MessageListField(ListField):
+    """List of messages with details of settings update status"""
+
+    message_id = Field('MessageId', required=True)
+    """The key for this message which can be used
+    to look up the message in a message registry
+    """
+
+    message = Field('Message')
+    """Human readable message, if provided"""
+
+    severity = MappedField('Severity',
+                           res_maps.SEVERITY_VALUE_MAP)
+    """Severity of the error"""
+
+    resolution = Field('Resolution')
+    """Used to provide suggestions on how to resolve
+    the situation that caused the error
+    """
+
+    _related_properties = Field('RelatedProperties')
+    """List of properties described by the message"""
+
+    message_args = Field('MessageArgs')
+    """List of message substitution arguments for the message
+    referenced by `message_id` from the message registry
+    """
+
+
+class FieldData(object):
+    """Contains data to be used when constructing Fields"""
+
+    def __init__(self, status_code, headers, json_doc):
+        """Initializes the FieldData instance"""
+        self._status_code = status_code
+        self._headers = headers
+        self._json_doc = json_doc
+
+    @property
+    def status_code(self):
+        """The status code"""
+        return self._status_code
+
+    @property
+    def headers(self):
+        """The headers"""
+        return self._headers
+
+    @property
+    def json_doc(self):
+        """The parsed JSON body"""
+        return self._json_doc
+
+
+class AbstractDataReader(object, metaclass=abc.ABCMeta):
 
     def set_connection(self, connector, path):
         """Sets mandatory connection parameters
@@ -341,27 +382,33 @@ class AbstractJsonReader(object):
         self._path = path
 
     @abc.abstractmethod
-    def get_json(self):
+    def get_data(self):
         """Based on data source get data and parse to JSON"""
 
 
-class JsonDataReader(AbstractJsonReader):
+class JsonDataReader(AbstractDataReader):
     """Gets the data from HTTP response given by path"""
 
-    def get_json(self):
+    def get_data(self):
         """Gets JSON file from URI directly"""
-        return self._conn.get(path=self._path).json()
+        data = self._conn.get(path=self._path)
+
+        json_data = data.json() if data.content else {}
+
+        return FieldData(data.status_code, data.headers, json_data)
 
 
-class JsonPublicFileReader(AbstractJsonReader):
+class JsonPublicFileReader(AbstractDataReader):
     """Loads the data from the Internet"""
 
-    def get_json(self):
+    def get_data(self):
         """Get JSON file from full URI"""
-        return self._conn.get(self._path).json()
+        data = self._conn.get(self._path)
+
+        return FieldData(data.status_code, data.headers, data.json())
 
 
-class JsonArchiveReader(AbstractJsonReader):
+class JsonArchiveReader(AbstractDataReader):
     """Gets the data from JSON file in archive"""
 
     def __init__(self, archive_file):
@@ -371,15 +418,16 @@ class JsonArchiveReader(AbstractJsonReader):
         """
         self._archive_file = archive_file
 
-    def get_json(self):
+    def get_data(self):
         """Gets JSON file from archive. Currently supporting ZIP only"""
 
         data = self._conn.get(path=self._path)
         if data.headers.get('content-type') == 'application/zip':
             try:
                 archive = zipfile.ZipFile(io.BytesIO(data.content))
-                return json.loads(archive.read(self._archive_file)
-                                  .decode(encoding='utf-8'))
+                json_data = json.loads(archive.read(self._archive_file)
+                                       .decode(encoding='utf-8'))
+                return FieldData(data.status_code, data.headers, json_data)
             except (zipfile.BadZipfile, ValueError) as e:
                 raise exceptions.ArchiveParsingError(
                     path=self._path, error=e)
@@ -387,8 +435,10 @@ class JsonArchiveReader(AbstractJsonReader):
             LOG.error('Support for %(type)s not implemented',
                       {'type': data.headers['content-type']})
 
+            return FieldData(data.status_code, data.headers, None)
 
-class JsonPackagedFileReader(AbstractJsonReader):
+
+class JsonPackagedFileReader(AbstractDataReader):
     """Gets the data from packaged file given by path"""
 
     def __init__(self, resource_package_name):
@@ -398,16 +448,31 @@ class JsonPackagedFileReader(AbstractJsonReader):
         """
         self._resource_package_name = resource_package_name
 
-    def get_json(self):
+    def get_data(self):
         """Gets JSON file from packaged file denoted by path"""
 
         with pkg_resources.resource_stream(self._resource_package_name,
                                            self._path) as resource:
-            return json.loads(resource.read().decode(encoding='utf-8'))
+            json_data = json.loads(resource.read().decode(encoding='utf-8'))
+            return FieldData(None, None, json_data)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ResourceBase(object):
+def get_reader(connector, path, reader=None):
+    """Create and configure the reader.
+
+    :param connector: A Connector instance
+    :param path: sub-URI path to the resource.
+    :param reader: Reader to use to fetch JSON data.
+    :returns: the reader
+    """
+    if reader is None:
+        reader = JsonDataReader()
+    reader.set_connection(connector, path)
+
+    return reader
+
+
+class ResourceBase(object, metaclass=abc.ABCMeta):
 
     redfish_version = None
     """The Redfish version"""
@@ -420,7 +485,8 @@ class ResourceBase(object):
                  path='',
                  redfish_version=None,
                  registries=None,
-                 reader=None):
+                 reader=None,
+                 json_doc=None):
         """A class representing the base of any Redfish resource
 
         Invokes the ``refresh()`` method of resource for the first
@@ -432,6 +498,7 @@ class ResourceBase(object):
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
         :param reader: Reader to use to fetch JSON data.
+        :param json_doc: parsed JSON document in form of Python types.
         """
         self._conn = connector
         self._path = path
@@ -443,12 +510,9 @@ class ResourceBase(object):
         # attribute values are fetched.
         self._is_stale = True
 
-        if reader is None:
-            reader = JsonDataReader()
-        reader.set_connection(connector, path)
-        self._reader = reader
+        self._reader = get_reader(connector, path, reader)
 
-        self.refresh()
+        self.refresh(json_doc=json_doc)
 
     def _parse_attributes(self, json_doc):
         """Parse the attributes of a resource.
@@ -461,7 +525,7 @@ class ResourceBase(object):
             # Hide the Field object behind the real value
             setattr(self, attr, field._load(json_doc, self))
 
-    def refresh(self, force=True):
+    def refresh(self, force=True, json_doc=None):
         """Refresh the resource
 
         Freshly retrieves/fetches the resource attributes and invokes
@@ -474,6 +538,7 @@ class ResourceBase(object):
         :param force: if set to False, will only refresh if the resource is
             marked as stale, otherwise neither it nor its subresources will
             be refreshed.
+        :param json_doc: parsed JSON document in form of Python types.
         :raises: ResourceNotFoundError
         :raises: ConnectionError
         :raises: HTTPError
@@ -483,7 +548,10 @@ class ResourceBase(object):
         if not self._is_stale and not force:
             return
 
-        self._json = self._reader.get_json()
+        if json_doc:
+            self._json = json_doc
+        else:
+            self._json = self._reader.get_data().json_doc
 
         LOG.debug('Received representation of %(type)s %(path)s: %(json)s',
                   {'type': self.__class__.__name__,
@@ -568,8 +636,7 @@ class ResourceBase(object):
         return self._registries
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ResourceCollectionBase(ResourceBase):
+class ResourceCollectionBase(ResourceBase, metaclass=abc.ABCMeta):
 
     name = Field('Name')
     """The name of the collection"""
