@@ -49,16 +49,28 @@ SYSTEM_POWER_STATE_POWERING_OFF = res_cons.POWER_STATE_POWERING_OFF
 # Indicator LED Constants
 
 SYSTEM_INDICATOR_LED_LIT = res_cons.INDICATOR_LED_LIT
-"""The Indicator LED is lit"""
+"""The Indicator LED is lit
+
+Deprecated: Use `sushy.resources.constants.INDICATOR_LED_LIT`.
+"""
 
 SYSTEM_INDICATOR_LED_BLINKING = res_cons.INDICATOR_LED_BLINKING
-"""The Indicator LED is blinking"""
+"""The Indicator LED is blinking
+
+Deprecated: Use `sushy.resources.constants.INDICATOR_LED_BLINKING`.
+"""
 
 SYSTEM_INDICATOR_LED_OFF = res_cons.INDICATOR_LED_OFF
-"""The Indicator LED is off"""
+"""The Indicator LED is off
+
+Deprecated: Use `sushy.resources.constants.INDICATOR_LED_OFF`.
+"""
 
 SYSTEM_INDICATOR_LED_UNKNOWN = res_cons.INDICATOR_LED_UNKNOWN
-"""The state of the Indicator LED cannot be determine"""
+"""The state of the Indicator LED cannot be determine
+
+Deprecated: Use `sushy.resources.constants.INDICATOR_LED_UNKNOWN`.
+"""
 
 # Boot source target constants
 
@@ -146,3 +158,18 @@ PROCESSOR_INSTRUCTIONSET_MIPS64 = 'MIPS 64-bit'
 PROCESSOR_INSTRUCTIONSET_OEM = 'OEM-defined'
 PROCESSOR_INSTRUCTIONSET_x86 = 'x86 32-bit'
 PROCESSOR_INSTRUCTIONSET_x86_64 = 'x86 64-bit'
+
+# System type constants
+
+SYSTEM_TYPE_PHYSICAL = "Physical"
+"""A physical computer system"""
+SYSTEM_TYPE_VIRTUAL = "Virtual"
+"""A virtual machine instance"""
+SYSTEM_TYPE_OS = "OS"
+"""An operating system instance"""
+SYSTEM_TYPE_PHYSICALLY_PARTITIONED = "PhysicallyPartitioned"
+"""A hardware-based partition of a computer system"""
+SYSTEM_TYPE_VIRTUALLY_PARTITIONED = "VirtuallyPartitioned"
+"""A virtual or software-based partition of a computer system"""
+SYSTEM_TYPE_COMPOSED = "Composed"
+"""A computer system created by binding resource blocks together"""
