@@ -12,7 +12,7 @@
 # limitations under the License.
 
 import json
-import mock
+from unittest import mock
 
 from sushy.resources.compositionservice import compositionservice
 from sushy.resources import constants as res_cons
