@@ -12,13 +12,12 @@
 # limitations under the License.
 
 import json
-import mock
+from unittest import mock
 
 from sushy import exceptions
 from sushy.resources.compositionservice import constants as res_block_cons
 from sushy.resources.compositionservice import resourceblock
 from sushy.resources import constants as res_cons
-
 from sushy.tests.unit import base
 
 
