@@ -12,10 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 import json
+from unittest import mock
 
-import mock
-from six.moves import http_client
 
 import sushy
 from sushy import exceptions
