@@ -14,8 +14,9 @@
 
 
 import json
-import mock
+from unittest import mock
 
+from sushy.resources.base import FieldData
 from sushy.resources.registry import message_registry_file
 from sushy.tests.unit import base
 
@@ -59,9 +60,9 @@ class MessageRegistryFileTestCase(base.TestCase):
     def test_get_message_registry_uri(self, mock_reader, mock_msg_reg):
         mock_reader_rv = mock.Mock()
         mock_reader.return_value = mock_reader_rv
-        mock_reader_rv.get_json.return_value = {
+        mock_reader_rv.get_data.return_value = FieldData(200, {}, {
             "@odata.type": "#MessageRegistry.v1_1_1.MessageRegistry",
-        }
+        })
         mock_msg_reg_rv = mock.Mock()
         mock_msg_reg.return_value = mock_msg_reg_rv
 
@@ -78,9 +79,9 @@ class MessageRegistryFileTestCase(base.TestCase):
         mock_reader_rv = mock.Mock()
         mock_reader.return_value = mock_reader_rv
         mock_msg_reg_rv = mock.Mock()
-        mock_reader_rv.get_json.return_value = {
+        mock_reader_rv.get_data.return_value = FieldData(200, {}, {
             "@odata.type": "#MessageRegistry.v1_1_1.MessageRegistry",
-        }
+        })
         mock_msg_reg.return_value = mock_msg_reg_rv
         self.reg_file.location[0].uri = None
 
@@ -100,9 +101,9 @@ class MessageRegistryFileTestCase(base.TestCase):
         mock_reader_rv = mock.Mock()
         mock_reader.return_value = mock_reader_rv
         mock_msg_reg_rv = mock.Mock()
-        mock_reader_rv.get_json.return_value = {
+        mock_reader_rv.get_data.return_value = FieldData(200, {}, {
             "@odata.type": "#MessageRegistry.v1_1_1.MessageRegistry",
-        }
+        })
         mock_msg_reg.return_value = mock_msg_reg_rv
         self.reg_file.location[0].uri = None
         self.reg_file.location[0].archive_uri = None
@@ -150,6 +151,48 @@ class MessageRegistryFileTestCase(base.TestCase):
             'No message registry found for %(language)s or default',
             {'language': 'en'})
 
+    @mock.patch('sushy.resources.registry.message_registry.MessageRegistry',
+                autospec=True)
+    @mock.patch('sushy.resources.registry.message_registry_file.RegistryType',
+                autospec=True)
+    @mock.patch('sushy.resources.registry.message_registry_file.LOG',
+                autospec=True)
+    def test_get_message_registry_invalid_uri(
+            self, mock_log, mock_msg_reg_type, mock_msg_reg):
+        mock_msg_reg_rv = mock.Mock()
+        mock_msg_reg.return_value = mock_msg_reg_rv
+        self.reg_file.location[0].uri = {'extref': 'http://127.0.0.1/reg'}
+        mock_msg_reg.side_effect = TypeError('Wrong URL type')
+        mock_msg_reg_type.return_value._odata_type = mock.MagicMock(
+            endswith=mock.MagicMock(return_value=True))
+
+        registry = self.reg_file.get_message_registry('en', None)
+
+        self.assertIsNone(registry)
+
+        mock_msg_reg_type.assert_called_once_with(
+            mock.ANY,
+            path={'extref': 'http://127.0.0.1/reg'}, reader=None,
+            redfish_version='1.0.2')
+
+        mock_msg_reg.assert_called_once_with(
+            mock.ANY,
+            path={'extref': 'http://127.0.0.1/reg'}, reader=None,
+            redfish_version='1.0.2')
+
+        expected_calls = [
+            mock.call(
+                'Cannot load message registry from location %(location)s: '
+                '%(error)s',
+                {'location': {'extref': 'http://127.0.0.1/reg'},
+                 'error': mock.ANY}),
+            mock.call(
+                'No message registry found for %(language)s or default',
+                {'language': 'en'})
+        ]
+
+        mock_log.warning.assert_has_calls(expected_calls)
+
     @mock.patch('sushy.resources.registry.message_registry_file.RegistryType',
                 autospec=True)
     def test_get_message_registry_non_default_lang(self, mock_registry_type):
@@ -191,6 +234,16 @@ class MessageRegistryFileTestCase(base.TestCase):
             'No message registry found for %(language)s or default',
             {'language': 'en'})
 
+    @mock.patch('sushy.resources.base.logging.warning',
+                autospec=True)
+    def test__parse_attributes_missing_registry(self, mock_log):
+        self.json_doc.pop('Registry')
+        self.reg_file._parse_attributes(self.json_doc)
+        self.assertEqual('UNKNOWN.0.0', self.reg_file.registry)
+        mock_log.assert_called_with(
+            'Applying default "UNKNOWN.0.0" on required, but missing '
+            'attribute "[\'Registry\']"')
+
 
 class MessageRegistryFileCollectionTestCase(base.TestCase):
 
