@@ -14,7 +14,7 @@
 #    under the License.
 
 import json
-import mock
+from unittest import mock
 
 from dateutil import parser
 
@@ -28,7 +28,6 @@ from sushy.resources.system import bios
 from sushy.resources.system import mappings as sys_map
 from sushy.resources.system import processor
 from sushy.resources.system import simple_storage
-from sushy.resources.system.storage import storage
 from sushy.resources.system import system
 from sushy.tests.unit import base
 
@@ -51,7 +50,7 @@ class SystemTestCase(base.TestCase):
         self.sys_inst._parse_attributes(self.json_doc)
         self.assertEqual('1.0.2', self.sys_inst.redfish_version)
         self.assertEqual('Chicago-45Z-2381', self.sys_inst.asset_tag)
-        self.assertEqual('P79 v1.33 (02/28/2015)', self.sys_inst.bios_version)
+        self.assertEqual('P79 v1.45 (12/06/2017)', self.sys_inst.bios_version)
         self.assertEqual('Web Front End node', self.sys_inst.description)
         self.assertEqual('web483', self.sys_inst.hostname)
         self.assertEqual('437XR1138R2', self.sys_inst.identity)
@@ -127,7 +126,8 @@ class SystemTestCase(base.TestCase):
                           "GracefulRestart",
                           "ForceRestart",
                           "Nmi",
-                          "ForceOn"
+                          "ForceOn",
+                          "PushPowerButton"
                           ],
                          value.allowed_values)
 
@@ -145,7 +145,8 @@ class SystemTestCase(base.TestCase):
                         sushy.RESET_FORCE_OFF,
                         sushy.RESET_FORCE_ON,
                         sushy.RESET_ON,
-                        sushy.RESET_NMI])
+                        sushy.RESET_NMI,
+                        sushy.RESET_PUSH_POWER_BUTTON])
         self.assertEqual(expected, values)
         self.assertIsInstance(values, set)
 
@@ -226,6 +227,64 @@ class SystemTestCase(base.TestCase):
         self.assertIsInstance(values, set)
         self.assertEqual(1, mock_log.call_count)
 
+    def test_set_system_boot_options(self):
+        self.sys_inst.set_system_boot_options(
+            sushy.BOOT_SOURCE_TARGET_PXE,
+            enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
+            mode=sushy.BOOT_SOURCE_MODE_UEFI)
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/437XR1138R2',
+            data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
+                           'BootSourceOverrideTarget': 'Pxe',
+                           'BootSourceOverrideMode': 'UEFI'}})
+
+    def test_set_system_boot_options_no_mode_specified(self):
+        self.sys_inst.set_system_boot_options(
+            sushy.BOOT_SOURCE_TARGET_HDD,
+            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/437XR1138R2',
+            data={'Boot': {'BootSourceOverrideEnabled': 'Once',
+                           'BootSourceOverrideTarget': 'Hdd'}})
+
+    def test_set_system_boot_options_no_target_specified(self):
+        self.sys_inst.set_system_boot_options(
+            enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
+            mode=sushy.BOOT_SOURCE_MODE_UEFI)
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/437XR1138R2',
+            data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
+                           'BootSourceOverrideMode': 'UEFI'}})
+
+    def test_set_system_boot_options_no_freq_specified(self):
+        self.sys_inst.set_system_boot_options(
+            target=sushy.BOOT_SOURCE_TARGET_PXE,
+            mode=sushy.BOOT_SOURCE_MODE_UEFI)
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/437XR1138R2',
+            data={'Boot': {'BootSourceOverrideTarget': 'Pxe',
+                           'BootSourceOverrideMode': 'UEFI'}})
+
+    def test_set_system_boot_options_nothing_specified(self):
+        self.sys_inst.set_system_boot_options()
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/437XR1138R2', data={})
+
+    def test_set_system_boot_options_invalid_target(self):
+        self.assertRaises(exceptions.InvalidParameterValueError,
+                          self.sys_inst.set_system_boot_source,
+                          'invalid-target')
+
+    def test_set_system_boot_options_invalid_enabled(self):
+        with self.assertRaisesRegex(
+            exceptions.InvalidParameterValueError,
+            '"enabled" value.*{0}'.format(
+                list(sys_map.BOOT_SOURCE_ENABLED_MAP_REV))):
+
+            self.sys_inst.set_system_boot_options(
+                sushy.BOOT_SOURCE_TARGET_HDD,
+                enabled='invalid-enabled')
+
     def test_set_system_boot_source(self):
         self.sys_inst.set_system_boot_source(
             sushy.BOOT_SOURCE_TARGET_PXE,
@@ -480,7 +539,7 @@ class SystemTestCase(base.TestCase):
                               simple_storage.SimpleStorageCollection)
 
     def test_storage_for_missing_attr(self):
-        self.sys_inst.json.pop('Storage')
+        self.sys_inst.json.pop('SimpleStorage')
         with self.assertRaisesRegex(
                 exceptions.MissingAttributeError, 'attribute Storage'):
             self.sys_inst.storage
@@ -492,16 +551,17 @@ class SystemTestCase(base.TestCase):
                   'storage_collection.json') as f:
             self.conn.get.return_value.json.return_value = json.load(f)
         # | WHEN |
-        actual_storage = self.sys_inst.storage
+        actual_storage = self.sys_inst.simple_storage
         # | THEN |
-        self.assertIsInstance(actual_storage, storage.StorageCollection)
+        self.assertIsInstance(actual_storage,
+                              simple_storage.SimpleStorageCollection)
         self.conn.get.return_value.json.assert_called_once_with()
 
         # reset mock
         self.conn.get.return_value.json.reset_mock()
         # | WHEN & THEN |
         # tests for same object on invoking subsequently
-        self.assertIs(actual_storage, self.sys_inst.storage)
+        self.assertIs(actual_storage, self.sys_inst.simple_storage)
         self.conn.get.return_value.json.assert_not_called()
 
     def test_storage_on_refresh(self):
@@ -510,8 +570,8 @@ class SystemTestCase(base.TestCase):
                   'storage_collection.json') as f:
             self.conn.get.return_value.json.return_value = json.load(f)
         # | WHEN & THEN |
-        self.assertIsInstance(self.sys_inst.storage,
-                              storage.StorageCollection)
+        self.assertIsInstance(self.sys_inst.simple_storage,
+                              simple_storage.SimpleStorageCollection)
 
         # On refreshing the system instance...
         with open('sushy/tests/unit/json_samples/system.json') as f:
@@ -525,7 +585,8 @@ class SystemTestCase(base.TestCase):
                   'storage_collection.json') as f:
             self.conn.get.return_value.json.return_value = json.load(f)
         # | WHEN & THEN |
-        self.assertIsInstance(self.sys_inst.storage, storage.StorageCollection)
+        self.assertIsInstance(self.sys_inst.simple_storage,
+                              simple_storage.SimpleStorageCollection)
 
     def test_managers(self):
         # | GIVEN |
