@@ -14,16 +14,15 @@
 #    under the License.
 
 import copy
+from http import client as http_client
 import io
 import json
-import mock
-
-from six.moves import http_client
+from unittest import mock
+import zipfile
 
 from sushy import exceptions
 from sushy.resources import base as resource_base
 from sushy.tests.unit import base
-import zipfile
 
 
 BASE_RESOURCE_JSON = {
