@@ -12,10 +12,11 @@
 # limitations under the License.
 
 import json
-import mock
+from unittest import mock
 
 from sushy import exceptions
 from sushy.resources import constants as res_cons
+from sushy.resources.taskservice import taskmonitor
 from sushy.resources.updateservice import constants as ups_cons
 from sushy.resources.updateservice import softwareinventory
 from sushy.resources.updateservice import updateservice
@@ -57,10 +58,23 @@ class UpdateServiceTestCase(base.TestCase):
             self.upd_serv._parse_attributes, self.json_doc)
 
     def test_simple_update(self):
-        self.upd_serv.simple_update(
+        with open('sushy/tests/unit/json_samples/task.json') as f:
+            task_json = json.load(f)
+        task_submitted = mock.Mock()
+        task_submitted.json.return_value = task_json
+        task_submitted.status_code = 202
+        task_submitted.headers = {'Content-Length': 42,
+                                  'Location': '/Task/545'}
+        self.conn.post.return_value = task_submitted
+
+        tm = self.upd_serv.simple_update(
             image_uri='local.server/update.exe',
             targets=['/redfish/v1/UpdateService/FirmwareInventory/BMC'],
             transfer_protocol=ups_cons.UPDATE_PROTOCOL_HTTPS)
+
+        self.assertIsInstance(tm, taskmonitor.TaskMonitor)
+        self.assertEqual('/Task/545', tm.task_monitor)
+
         self.upd_serv._conn.post.assert_called_once_with(
             '/redfish/v1/UpdateService/Actions/SimpleUpdate',
             data={
@@ -68,7 +82,32 @@ class UpdateServiceTestCase(base.TestCase):
                 'Targets': ['/redfish/v1/UpdateService/FirmwareInventory/BMC'],
                 'TransferProtocol': 'HTTPS'})
 
+    def test_simple_update_missing_location(self):
+        with open('sushy/tests/unit/json_samples/task.json') as f:
+            task_json = json.load(f)
+        task_submitted = mock.Mock()
+        task_submitted.json.return_value = task_json
+        task_submitted.status_code = 202
+        task_submitted.headers = {'Allow': 'GET'}
+        self.conn.post.return_value = task_submitted
+
+        self.assertRaises(
+            exceptions.MissingHeaderError,
+            self.upd_serv.simple_update,
+            image_uri='local.server/update.exe',
+            targets='/redfish/v1/UpdateService/Actions/SimpleUpdate',
+            transfer_protocol='HTTPS')
+
     def test_simple_update_backward_compatible_protocol(self):
+        with open('sushy/tests/unit/json_samples/task.json') as f:
+            task_json = json.load(f)
+        task_submitted = mock.Mock()
+        task_submitted.json.return_value = task_json
+        task_submitted.status_code = 202
+        task_submitted.headers = {'Content-Length': 42,
+                                  'Location': '/Task/545'}
+        self.conn.post.return_value = task_submitted
+
         self.upd_serv.simple_update(
             image_uri='local.server/update.exe',
             targets='/redfish/v1/UpdateService/Actions/SimpleUpdate',
@@ -81,6 +120,14 @@ class UpdateServiceTestCase(base.TestCase):
                 'TransferProtocol': 'HTTPS'})
 
     def test_simple_update_without_target(self):
+        with open('sushy/tests/unit/json_samples/task.json') as f:
+            task_json = json.load(f)
+        task_submitted = mock.Mock()
+        task_submitted.json.return_value = task_json
+        task_submitted.status_code = 202
+        task_submitted.headers = {'Content-Length': 42,
+                                  'Location': '/Task/545'}
+        self.conn.post.return_value = task_submitted
         self.upd_serv.simple_update(
             image_uri='local.server/update.exe',
             transfer_protocol='HTTPS')
@@ -98,42 +145,48 @@ class UpdateServiceTestCase(base.TestCase):
             targets='/redfish/v1/UpdateService/Actions/SimpleUpdate',
             transfer_protocol='ROYAL')
 
-    def test_software_inventory(self):
-        # | GIVEN |
-        self.conn.get.return_value.json.reset_mock()
-        with open('sushy/tests/unit/json_samples/'
-                  'softwareinventory_collection.json') as f:
-            self.conn.get.return_value.json.return_value = json.load(f)
-        # | WHEN |
-        actual_software_inventory = self.upd_serv.software_inventory
-        # | THEN |
-        self.assertIsInstance(actual_software_inventory,
-                              softwareinventory.SoftwareInventoryCollection)
-        self.conn.get.return_value.json.assert_called_once_with()
+    @mock.patch.object(softwareinventory, 'SoftwareInventoryCollection',
+                       autospec=True)
+    def test_software_inventory(self, software_inventory_collection_mock):
+        self.upd_serv.software_inventory
+        software_inventory_collection_mock.assert_called_once_with(
+            self.conn, '/redfish/v1/UpdateService/SoftwareInventory',
+            self.upd_serv.redfish_version,
+            self.upd_serv._registries)
 
-        # reset mock
-        self.conn.get.return_value.json.reset_mock()
-        # | WHEN & THEN |
-        self.assertIs(actual_software_inventory,
-                      self.upd_serv.software_inventory)
-        self.conn.get.return_value.json.assert_not_called()
+    @mock.patch.object(softwareinventory, 'SoftwareInventoryCollection',
+                       autospec=True)
+    def test_firmware_inventory(self, software_inventory_collection_mock):
+        self.upd_serv.firmware_inventory
+        software_inventory_collection_mock.assert_called_once_with(
+            self.conn, '/redfish/v1/UpdateService/FirmwareInventory',
+            self.upd_serv.redfish_version,
+            self.upd_serv._registries)
 
-    def test_firmware_inventory(self):
-        # | GIVEN |
-        self.conn.get.return_value.json.reset_mock()
-        with open('sushy/tests/unit/json_samples/'
-                  'softwareinventory_collection.json') as f:
-            self.conn.get.return_value.json.return_value = json.load(f)
-        # | WHEN |
-        actual_firmware_inventory = self.upd_serv.firmware_inventory
-        # | THEN |
-        self.assertIsInstance(actual_firmware_inventory,
-                              softwareinventory.SoftwareInventoryCollection)
-        self.conn.get.return_value.json.assert_called_once_with()
 
-        # reset mock
-        self.conn.get.return_value.json.reset_mock()
-        # | WHEN & THEN |
-        self.assertIs(actual_firmware_inventory,
-                      self.upd_serv.firmware_inventory)
-        self.conn.get.return_value.json.assert_not_called()
+class UpdateServiceNoInvTestCase(base.TestCase):
+
+    def setUp(self):
+        super(UpdateServiceNoInvTestCase, self).setUp()
+        self.conn = mock.Mock()
+        no_inv_json = 'sushy/tests/unit/json_samples/updateservice_no_inv.json'
+        with open(no_inv_json) as f:
+            self.json_doc = json.load(f)
+
+        self.conn.get.return_value.json.return_value = self.json_doc
+
+        self.upd_serv = updateservice.UpdateService(
+            self.conn, '/redfish/v1/UpdateService/UpdateService',
+            redfish_version='1.3.0')
+
+    def test_software_inventory_when_sw_inv_absent(self):
+        self.assertRaisesRegex(
+            exceptions.MissingAttributeError,
+            'SoftwareInventory/@odata.id',
+            getattr, self.upd_serv, 'software_inventory')
+
+    def test_firmware_inventory_when_fw_inv_absent(self):
+        self.assertRaisesRegex(
+            exceptions.MissingAttributeError,
+            'FirmwareInventory/@odata.id',
+            getattr, self.upd_serv, 'firmware_inventory')
